# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

cloudApiKey: Optional[str]
"""
The Confluent Cloud API Key.
"""

cloudApiSecret: Optional[str]
"""
The Confluent Cloud API Secret.
"""

endpoint: Optional[str]
"""
The base endpoint of Confluent Cloud API.
"""

environmentId: Optional[str]
"""
The Flink Environment ID.
"""

flinkApiKey: Optional[str]
"""
The Flink API Key.
"""

flinkApiSecret: Optional[str]
"""
The Flink API Secret.
"""

flinkComputePoolId: Optional[str]
"""
The Flink Compute Pool ID.
"""

flinkPrincipalId: Optional[str]
"""
The Flink Principal ID.
"""

flinkRestEndpoint: Optional[str]
"""
The Flink REST Endpoint.
"""

kafkaApiKey: Optional[str]
"""
The Kafka Cluster API Key.
"""

kafkaApiSecret: Optional[str]
"""
The Kafka Cluster API Secret.
"""

kafkaId: Optional[str]
"""
The Kafka Cluster ID.
"""

kafkaRestEndpoint: Optional[str]
"""
The Kafka Cluster REST Endpoint.
"""

maxRetries: Optional[int]
"""
Maximum number of retries of HTTP client. Defaults to 4.
"""

organizationId: Optional[str]
"""
The Flink Organization ID.
"""

schemaRegistryApiKey: Optional[str]
"""
The Schema Registry Cluster API Key.
"""

schemaRegistryApiSecret: Optional[str]
"""
The Schema Registry Cluster API Secret.
"""

schemaRegistryId: Optional[str]
"""
The Schema Registry Cluster ID.
"""

schemaRegistryRestEndpoint: Optional[str]
"""
The Schema Registry Cluster REST Endpoint.
"""

